@@ -22,6 +22,9 @@ import tables
 warnings.simplefilter('ignore', category=tables.NaturalNameWarning)
 
 from autopilot import prefs
+from autopilot.core.loggers import init_logger
+
+
 
 if __name__ == '__main__':
     # Parse arguments - this should have been called with a .json prefs file passed
@@ -43,10 +46,10 @@ if __name__ == '__main__':
 
     prefs.init(prefs_file)
 
-    if hasattr(prefs, 'AUDIOSERVER') or 'AUDIO' in prefs.CONFIG:
-        if prefs.AUDIOSERVER == 'pyo':
+    if prefs.get('AUDIOSERVER') or 'AUDIO' in prefs.get('CONFIG'):
+        if prefs.get('AUDIOSERVER') == 'pyo':
             from autopilot.stim.sound import pyoserver
-        elif prefs.AUDIOSERVER in ('jack', True):
+        else:
             from autopilot.stim.sound import jackclient
 
 from autopilot.core.networking import Pilot_Station, Net_Node, Message
@@ -117,20 +120,17 @@ class Pilot:
         ip (str): Our IPv4 address
         listens (dict): Dictionary mapping message keys to methods used to process them.
         logger (:class:`logging.Logger`): Used to log messages and network events.
-        log_handler (:class:`logging.FileHandler`): Handler for logging
-        log_formatter (:class:`logging.Formatter`): Formats log entries as::
-
-            "%(asctime)s %(levelname)s : %(message)s"
     """
 
     logger = None
-    log_handler = None
-    log_formatter = None
+
 
     # Events for thread handling
     running = None
     stage_block = None
     file_block = None
+    quitting = None
+    """mp.Event to signal when process is quitting"""
 
     # networking - our internal and external messengers
     node = None
@@ -150,28 +150,32 @@ class Pilot:
                 print('')
                 sys.stdout.flush()
 
-        self.name = prefs.NAME
-        if prefs.LINEAGE == "CHILD":
+        self.name = prefs.get('NAME')
+        if prefs.get('LINEAGE') == "CHILD":
             self.child = True
-            self.parentid = prefs.PARENTID
+            self.parentid = prefs.get('PARENTID')
         else:
             self.child = False
             self.parentid = 'T'
 
-        self.init_logging()
+        self.logger = init_logger(self)
+        self.logger.debug('pilot logger initialized')
 
         # Locks, etc. for threading
         self.running = threading.Event() # Are we running a task?
         self.stage_block = threading.Event() # Are we waiting on stage triggers?
         self.file_block = threading.Event() # Are we waiting on file transfer?
+        self.quitting = threading.Event()
+        self.quitting.clear()
 
         # init pigpiod process
         self.init_pigpio()
 
         # Init audio server
-        if hasattr(prefs, 'AUDIOSERVER') or 'AUDIO' in prefs.CONFIG:
+        if prefs.get('AUDIOSERVER') or 'AUDIO' in prefs.get('CONFIG'):
             self.init_audio()
 
+
         # Init Station
         # Listen dictionary - what do we do when we receive different messages?
         self.listens = {
@@ -188,19 +192,21 @@ class Pilot:
         self.networking.start()
         self.node = Net_Node(id = "_{}".format(self.name),
                              upstream = self.name,
-                             port = prefs.MSGPORT,
+                             port = prefs.get('MSGPORT'),
                              listens = self.listens,
                              instance=False)
+        self.logger.debug('pilot networking initialized')
 
         # if we need to set pins pulled up or down, do that now
         self.pulls = []
-        if hasattr(prefs, 'PULLUPS'):
-            for pin in prefs.PULLUPS:
+        if prefs.get( 'PULLUPS'):
+            for pin in prefs.get('PULLUPS'):
                 self.pulls.append(gpio.Digital_Out(int(pin), pull='U', polarity=0))
-        if hasattr(prefs, 'PULLDOWNS'):
-            for pin in prefs.PULLDOWNS:
+        if prefs.get( 'PULLDOWNS'):
+            for pin in prefs.get('PULLDOWNS'):
                 self.pulls.append(gpio.Digital_Out(int(pin), pull='D', polarity=1))
 
+        self.logger.debug('pullups and pulldowns set')
         # check if the calibration file needs to be updated
 
 
@@ -211,6 +217,7 @@ class Pilot:
         # Since we're starting up, handshake to introduce ourselves
         self.ip = self.get_ip()
         self.handshake()
+        self.logger.debug('handshake sent')
 
 
 
@@ -218,25 +225,7 @@ class Pilot:
 
         # TODO Synchronize system clock w/ time from terminal.
 
-    def init_logging(self):
-        """
-        Start logging to a timestamped file in `prefs.LOGDIR`
-        """
 
-        timestr = datetime.datetime.now().strftime('%y%m%d_%H%M%S')
-        log_file = os.path.join(prefs.LOGDIR, 'Pilots_Log_{}.log'.format(timestr))
-
-        self.logger = logging.getLogger('main')
-        self.log_handler = logging.FileHandler(log_file)
-        self.log_formatter = logging.Formatter("%(asctime)s %(levelname)s : %(message)s")
-        self.log_handler.setFormatter(self.log_formatter)
-        self.logger.addHandler(self.log_handler)
-        if hasattr(prefs, 'LOGLEVEL'):
-            loglevel = getattr(logging, prefs.LOGLEVEL)
-        else:
-            loglevel = logging.WARNING
-        self.logger.setLevel(loglevel)
-        self.logger.info('Pilot Logging Initiated')
 
     #################################################################
     # Station
@@ -313,7 +302,7 @@ class Pilot:
 
             # Make a group for this subject if we don't already have one
             self.subject = value['subject']
-            prefs.add('SUBJECT', self.subject)
+            prefs.set('SUBJECT', self.subject)
 
 
 
@@ -408,7 +397,7 @@ class Pilot:
             iti (int, float): how long we should :func:`~time.sleep` between openings
 
         """
-        pin_num = prefs.HARDWARE['PORTS'][port_name]
+        pin_num = prefs.get('HARDWARE')['PORTS'][port_name]
         port = gpio.Solenoid(pin_num, duration=int(open_dur))
         msg = {'click_num': 0,
                'pilot': self.name,
@@ -435,7 +424,7 @@ class Pilot:
         """
 
         # files for storing raw and fit calibration results
-        cal_fn = os.path.join(prefs.BASEDIR, 'port_calibration.json')
+        cal_fn = os.path.join(prefs.get('BASEDIR'), 'port_calibration.json')
 
         if os.path.exists(cal_fn):
             try:
@@ -534,14 +523,14 @@ class Pilot:
             path: If present, use calibration file specified, otherwise use default.
         """
 
-        lut_fn = os.path.join(prefs.BASEDIR, 'port_calibration_fit.json')
+        lut_fn = os.path.join(prefs.get('BASEDIR'), 'port_calibration_fit.json')
 
         if not calibration:
             # if we weren't given calibration results, load them
             if path:
                 open_fn = path
             else:
-                open_fn = os.path.join(prefs.BASEDIR, "port_calibration.json")
+                open_fn = os.path.join(prefs.get('BASEDIR'), "port_calibration.json")
 
             with open(open_fn, 'r') as open_f:
                 calibration = json.load(open_f)
@@ -579,6 +568,7 @@ class Pilot:
     def init_pigpio(self):
         try:
             self.pigpiod = external.start_pigpiod()
+            self.logger.debug('pigpio daemon started')
         except ImportError as e:
             self.pigpiod = None
             self.logger.exception(e)
@@ -586,15 +576,15 @@ class Pilot:
     def init_audio(self):
         """
         Initialize an audio server depending on the value of
-        `prefs.AUDIOSERVER`
+        `prefs.get('AUDIOSERVER')`
 
         * 'pyo' = :func:`.pyoserver.pyo_server`
         * 'jack' = :class:`.jackclient.JackClient`
         """
-        if prefs.AUDIOSERVER == 'pyo':
+        if prefs.get('AUDIOSERVER') == 'pyo':
             self.server = pyoserver.pyo_server()
             self.logger.info("pyo server started")
-        elif prefs.AUDIOSERVER in ('jack', True):
+        elif prefs.get('AUDIOSERVER') in ('jack', True):
             self.jackd = external.start_jackd()
             self.server = jackclient.JackClient()
             self.server.start()
@@ -603,14 +593,14 @@ class Pilot:
 
     def blank_LEDs(self):
         """
-        If any 'LEDS' are defined in `prefs.HARDWARE` ,
+        If any 'LEDS' are defined in `prefs.get('HARDWARE')` ,
         instantiate them, set their color to [0,0,0],
         and then release them.
         """
-        if 'LEDS' not in prefs.HARDWARE.keys():
+        if 'LEDS' not in prefs.get('HARDWARE').keys():
             return
 
-        for position, pins in prefs.HARDWARE['LEDS'].items():
+        for position, pins in prefs.get('HARDWARE')['LEDS'].items():
             led = gpio.LED_RGB(pins=pins)
             time.sleep(1.)
             led.set_color(col=[0,0,0])
@@ -623,7 +613,7 @@ class Pilot:
         """
         Setup a table to store data locally.
 
-        Opens `prefs.DATADIR/local.h5`, creates a group for the current subject,
+        Opens `prefs.get('DATADIR')/local.h5`, creates a group for the current subject,
         a new table for the current day.
 
         .. todo::
@@ -634,7 +624,7 @@ class Pilot:
             (:class:`tables.File`, :class:`tables.Table`,
             :class:`tables.tableextension.Row`): The file, table, and row for the local data table
         """
-        local_file = os.path.join(prefs.DATADIR, 'local.h5')
+        local_file = os.path.join(prefs.get('DATADIR'), 'local.h5')
         try:
             h5f = tables.open_file(local_file, mode='a')
         except (IOError, tables.HDF5ExtError) as e:
@@ -747,8 +737,12 @@ class Pilot:
 if __name__ == "__main__":
 
 
-    a = Pilot()
-
+    try:
+        a = Pilot()
+        a.quitting.wait()
+    except KeyboardInterrupt:
+        a.quitting.set()
+        sys.exit()
 
 
 
