@@ -2,6 +2,6 @@ from autopilot import prefs
 
 from autopilot.stim.managers import Stim_Manager, Proportional, init_manager
 
-if prefs.AGENT == "pilot":
-    if 'AUDIO' in prefs.CONFIG:
+if prefs.get('AGENT') == "pilot":
+    if 'AUDIO' in prefs.get('CONFIG'):
         from autopilot.stim.sound import sounds
